@@ -1,5 +1,3 @@
-use std::env;
-
 mod cli;
 mod conf;
 mod git;
@@ -7,7 +5,7 @@ mod inputs;
 mod utils;
 
 fn main() {
-	let args = cli::parse_args(env::args().collect());
+	let args = cli::parse_args();
 	let config = conf::read().expect("Failed to read from configuration file");
 	let inputs = inputs::get_inputs(&config).expect("Failed to get scope");
 	git::commit_changes(&config, &args, &inputs).expect("Failed to commit changes");
